==> kdeedu-3.0.1.tar.bz2: kdeedu-3.0.1/keduca/keduca/keducaprefs.h <==
/***************************************************************************
                          keducaprefs.h  -  description
                             -------------------
    begin                : Sat Jun 2 2001
    copyright            : (C) 2001 by Javier Campos
    email                : javi_cms@terra.es
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KEDUCAPREFS_H
#define KEDUCAPREFS_H

#include <qwidget.h>
#include <kdialogbase.h>

#include <qradiobutton.h>

/**KDialog preferences
  *@author Javier Campos
  */

class keducaprefs : public KDialogBase  {
   Q_OBJECT
public: 
	keducaprefs(QWidget *parent=0, const char *name=0, bool modal=true);
	~keducaprefs();
private: // Private methods
  /** Set page general */
  void setPageGeneral();
  /** Write settings */
  void configWrite();
  /** Read settings */
  void configRead();
private: // Private attributes
  /** Show result after next */
  QRadioButton *result_afternext;
  /** Show results after finish */
  QRadioButton *result_afterfinish;
private slots: // Private slots
  /** Push ok button */
  void slotOk();
};

#endif

==> kdeedu-3.1.tar.bz2: kdeedu-3.1/keduca/keduca/keducaprefs.h <==
/***************************************************************************
                          keducaprefs.h  -  description
                             -------------------
    begin                : Sat Jun 2 2001
    copyright            : (C) 2001 by Javier Campos
    email                : javi_cms@terra.es
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KEDUCAPREFS_H
#define KEDUCAPREFS_H

#include <qwidget.h>
#include <kdialogbase.h>

#include <qradiobutton.h>

/** Preferences for KEduca TestMaster (class KEduca)
 *@author Javier Campos
 */

class KEducaPrefs : public KDialogBase  {
    Q_OBJECT

public:
    KEducaPrefs(QWidget *parent=0, const char *name=0, bool modal=true);
    ~KEducaPrefs();

private: // Private methods
    /** Set page general */
    void setPageGeneral();
    /** Write settings */
    void configWrite();
    /** Read settings */
    void configRead();

private: // Private attributes
    /** Show result after next */
    QRadioButton *_resultAfterNext;
    /** Show results after finish */
    QRadioButton *_resultAfterFinish;

private slots: // Private slots
    /** Push ok button */
    void slotOk();
};

#endif
